==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/io/VanillaIoAdapter.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.io
{
	/// <summary>base class for IoAdapters that delegate to other IoAdapters (decorator pattern)
	/// 	</summary>
	public abstract class VanillaIoAdapter : com.db4o.io.IoAdapter
	{
		protected com.db4o.io.IoAdapter _delegate;

		public VanillaIoAdapter(com.db4o.io.IoAdapter delegateAdapter)
		{
			_delegate = delegateAdapter;
		}

		protected VanillaIoAdapter(com.db4o.io.IoAdapter delegateAdapter, string path, bool
			 lockFile, long initialLength)
		{
			_delegate = delegateAdapter.open(path, lockFile, initialLength);
		}

		public override void close()
		{
			_delegate.close();
		}

		public override long getLength()
		{
			return _delegate.getLength();
		}

		public override int read(byte[] bytes, int length)
		{
			return _delegate.read(bytes, length);
		}

		public override void seek(long pos)
		{
			_delegate.seek(pos);
		}

		public override void sync()
		{
			_delegate.sync();
		}

		public override void write(byte[] buffer, int length)
		{
			_delegate.write(buffer, length);
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/io/VanillaIoAdapter.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.io
{
	/// <summary>base class for IoAdapters that delegate to other IoAdapters (decorator pattern)
	/// 	</summary>
	public abstract class VanillaIoAdapter : com.db4o.io.IoAdapter
	{
		protected com.db4o.io.IoAdapter _delegate;

		public VanillaIoAdapter(com.db4o.io.IoAdapter delegateAdapter)
		{
			_delegate = delegateAdapter;
		}

		protected VanillaIoAdapter(com.db4o.io.IoAdapter delegateAdapter, string path, bool
			 lockFile, long initialLength)
		{
			_delegate = delegateAdapter.Open(path, lockFile, initialLength);
		}

		public override void Close()
		{
			_delegate.Close();
		}

		public override void Delete(string path)
		{
			_delegate.Delete(path);
		}

		public override bool Exists(string path)
		{
			return _delegate.Exists(path);
		}

		public override long GetLength()
		{
			return _delegate.GetLength();
		}

		public override int Read(byte[] bytes, int length)
		{
			return _delegate.Read(bytes, length);
		}

		public override void Seek(long pos)
		{
			_delegate.Seek(pos);
		}

		public override void Sync()
		{
			_delegate.Sync();
		}

		public override void Write(byte[] buffer, int length)
		{
			_delegate.Write(buffer, length);
		}
	}
}
